pub struct Cmp20SignSession { /* private fields */ }Trait Implementations
Sourceimpl SessionImpl for Cmp20SignSession
impl SessionImpl for Cmp20SignSession
Sourcefn round(&mut self, incoming: &[Message]) -> Result<RoundResult>
fn round(&mut self, incoming: &[Message]) -> Result<RoundResult>
Advance one round. Consumes the messages received since the last
round and returns the messages to send next, plus a
complete
flag indicating the session has produced its output and no more
rounds are needed.Auto Trait Implementations
impl Freeze for Cmp20SignSession
impl RefUnwindSafe for Cmp20SignSession
impl Send for Cmp20SignSession
impl Sync for Cmp20SignSession
impl Unpin for Cmp20SignSession
impl UnsafeUnpin for Cmp20SignSession
impl UnwindSafe for Cmp20SignSession